/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * SECTION:kiba-title
 * @short_description: Title for #KibaObject's.
 * @see_also:#KibaObject
 *
 * Title for #KibaObject's.
 */

#ifndef __KIBA_TITLE_H__
#define __KIBA_TITLE_H__

#include <gdk/gdk.h>
#include <cairo.h>

#include <kiba-types.h>

G_BEGIN_DECLS

#define KIBA_TYPE_TITLE           (kiba_title_get_type ())
#define KIBA_TITLE(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_TITLE, KibaTitle))
#define KIBA_TITLE_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_TITLE,  KibaTitleClass))
#define KIBA_IS_TITLE(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_TITLE))
#define KIBA_IS_TITLE_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_TITLE))
#define KIBA_TITLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_TITLE, KibaTitleClass))

typedef struct _KibaTitle KibaTitle;
typedef struct _KibaTitleClass KibaTitleClass;

/**
 * KibaTitleStyle:
 * @file: The pattern file path, or NULL.
 * @border_style: Border style.
 * @border_width: Border width.
 * @bg_affection: Affection for linear style.
 * @bg_step_size: Step size for radial/linear style.
 * @rgba: Text color.
 * @highlightColor: highlight color.
 * @shadow_rgba: background color.
 * @border_rgba: border color.
 * @gradient: array of colors.
 * @numColors: num of colors in @gradient.
 *
 * Title style struct.
 */
typedef struct {
	char *file;

	KibaCornerShape border_style;
	float border_width;
	float bg_affection;
	float bg_step_size;
	KibaRGBA rgba;
	KibaRGBA highlightColor;
	KibaRGBA shadow_rgba;
	KibaRGBA border_rgba;
	KibaRGBA *gradient;
	gint numColors;
}KibaTitleStyle;

/**
 * KibaTitleFlag:
 * @KIBA_TITLE_SCALING: scale title on hiding?
 * @KIBA_TITLE_DRAWABLE: draw the title?
 * @KIBA_TITLE_HIGHLIGHTING: highlight the title?
 *
 * Title flags enum.
 */
typedef enum {
	KIBA_TITLE_SCALING = 0,
	KIBA_TITLE_DRAWABLE,
	KIBA_TITLE_HIGHLIGHTING
}KibaTitleFlag;

KibaTitle* kiba_title_new ();

gboolean kiba_title_is_shown (KibaTitle *title);

void kiba_title_set_style (KibaTitle *title,
                           KibaTitleStyle style);

void kiba_title_set_flag (KibaTitle *title,
                          KibaTitleFlag flag);

void kiba_title_unset_flag (KibaTitle *title,
                            KibaTitleFlag flag);

gboolean kiba_title_get_flag (KibaTitle *title,
                              KibaTitleFlag flag);

void kiba_title_set_font (KibaTitle *title,
                          char *font);

KibaTitleStyle* kiba_title_get_style (KibaTitle *title);

void kiba_title_set_hide_delay (KibaTitle *title,
                                gint hide_delay);

void kiba_title_add_object (KibaTitle *title,
		GtkWidget *widget, KibaPosition position);

void kiba_title_show_object (KibaTitle *title,
		GtkWidget *widget, KibaPosition position);

void kiba_title_hide_object (KibaTitle *title,
		GtkWidget *widget);

gboolean kiba_title_object_is_shown (KibaTitle *title,
		GtkWidget *widget);

void kiba_title_set_object_text (KibaTitle *title,
		GtkWidget *widget,
		const char *text);

const char* kiba_title_get_object_text (KibaTitle *title,
		GtkWidget *widget);

void kiba_title_remove_object (KibaTitle *title,
		GtkWidget *widget);

G_END_DECLS

#endif
